<?php

declare(strict_types=1);

namespace Dedi\SyliusMegamenuPlugin\Entity;

use Dedi\SyliusMegamenuPlugin\Enum\EntryTypes;
use Dedi\SyliusMegamenuPlugin\Form\Listener\AdAwareInterface;
use Doctrine\Common\Collections\Collection;
use Sylius\Component\Core\Model\TaxonInterface;
use Sylius\Component\Resource\Model\TranslationInterface;

class ProductCatalogEntry extends Entry implements ProductCatalogEntryInterface
{
    public function getType(): string
    {
        return EntryTypes::PRODUCT_CATALOG;
    }

    protected function createTranslation(): TranslationInterface
    {
        return new ProductCatalogEntryTranslation();
    }

    public function getTaxons(): Collection
    {
        return $this->getTranslation()->getTaxons();
    }

    public function getRootTaxons(): Collection
    {
        return $this->getTranslation()->getRootTaxons();
    }

    public function addTaxon(TaxonInterface $taxon): ProductCatalogEntryInterface
    {
        return $this->getTranslation()->addTaxon($taxon);
    }

    public function removeTaxon(TaxonInterface $taxon): ProductCatalogEntryInterface
    {
        return $this->getTranslation()->removeTaxon($taxon);
    }

    public function hasTaxon(TaxonInterface $taxon): bool
    {
        return $this->getTranslation()->hasTaxon($taxon);
    }

    public function getAdImage(): ?string
    {
        return $this->getTranslation()->getAdImage();
    }

    public function setAdImage(?string $adImage): AdAwareInterface
    {
        $this->getTranslation()->setAdImage($adImage);

        return $this;
    }

    public function getAdUrl(): ?string
    {
        return $this->getTranslation()->getAdUrl();
    }

    public function setAdUrl(?string $adUrl): AdAwareInterface
    {
        $this->getTranslation()->setAdUrl($adUrl);

        return $this;
    }
}
